@@ -1,5 +1,5 @@
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: ggnotify.c,v 1.5 2004/02/18 12:49:22 lukasz Exp $
+ *  $Id: ggnotify.c,v 1.6 2004/06/15 10:37:56 alec Exp $
  */
 
 #include <stdio.h>
@@ -116,7 +116,7 @@ void reload(GLOBAL *g, struct ggnotify_module *n)
 						
 								unsigned char *select, *date, *value, *comment, *last_ten, *temp, *temp2;
 					
-								select = strdup("SELECT value, comment, time FROM cash WHERE userid = %id ORDER BY time LIMIT 10");
+								select = strdup("SELECT CASE WHEN type=4 THEN value*-1 ELSE value END AS value, comment, time FROM cash WHERE userid = %id ORDER BY time LIMIT 10");
 								g->str_replace(&select, "%id", g->db_get_data(res,i,"id"));
 						
 								if( (result = g->db_query(select))!=NULL ) {
