@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,30 +21,29 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dbview.php,v 1.17 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: dbview.php,v 1.19 2004/03/11 17:24:21 lukasz Exp $
  */
 
-$layout[pagetitle]="Podgld bazy danych";
+$layout['pagetitle'] = "Podgld bazy danych";
 
-$database = $LMS->DatabaseFetchContent($_GET[db]);
+$database = $LMS->DatabaseFetchContent($_GET['db']);
 
-if($_GET[rawmode]=="true")
+if($_GET['rawmode']=="true")
 {
-	$database[rawmode] = TRUE;
-	if($_GET[save]=="true")
+	$database['rawmode'] = TRUE;
+	if($_GET['save']=="true")
 	{
 		header("Content-Type: application/octetstream");
-		header("Content-Disposition: attachment; filename=lms-backup-".date("Ymd-His",$_GET[db]).".sql");
+		header("Content-Disposition: attachment; filename=lms-backup-".date("Ymd-His",$_GET['db']).".sql");
 	}
 	else
 		header("Content-Type: text/plain; charset=ISO-8859-2");
 }
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("database",$database);
-if(!$database[rawmode])
-	$SMARTY->display("header.html");
-$SMARTY->display("dbview.html");
-if(!$database[rawmode])
-	$SMARTY->display("footer.html");
+$SMARTY->assign('database',$database);
+if(!$database['rawmode'])
+	$SMARTY->display('header.html');
+$SMARTY->display('dbview.html');
+if(!$database['rawmode'])
+	$SMARTY->display('footer.html');
 ?>
\ No newline at end of file
