@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevinfo.php,v 1.14 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: netdevinfo.php,v 1.15 2004/03/11 17:24:22 lukasz Exp $
  */
 
 if(! $LMS->NetDevExists($_GET['id']))
@@ -63,7 +63,6 @@ $SMARTY->assign('netcomplist',$netcomplist);
 $SMARTY->assign('restnetdevlist',$netdevlist);
 $SMARTY->assign('netdevips',$netdevips);
 $SMARTY->assign('nodelist',$nodelist);
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('replacelist',$replacelist);
 $SMARTY->assign('replacelisttotal',$replacelisttotal);
 $SMARTY->assign('nodeipdata',$LMS->GetNode($_GET['ip']));
