@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,28 +21,30 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeedit.php,v 1.50 2004/05/16 14:09:50 alec Exp $
+ *  $Id: nodeedit.php,v 1.54 2004/07/21 19:59:09 alec Exp $
  */
 
 if(!$LMS->NodeExists($_GET['id']))
 	if(isset($_GET['ownerid']))
-		header("Location: ?m=userinfo&id=".$_GET['ownerid']);
+		header('Location: ?m=userinfo&id='.$_GET['ownerid']);
 	else
-		header("Location: ?m=nodelist");
+		header('Location: ?m=nodelist');
 
-if($_GET['action']=="link")
+if($_GET['action']=='link')
 {
 	$netdev = $LMS->GetNetDev($_GET['devid']); 
-	if($netdev['ports'] <= $netdev['takenports'])
-	        $error['netdev'] = "Brak wolnych portw w wybranym urzdzeniu!";
-	$errorlinkdev = $netdev;
 
-	if(!$error) 
+	if($netdev['ports'] > $netdev['takenports']) 
 	{
 		$LMS->NetDevLinkNode($_GET['id'],$_GET['devid']);
-		header("Location: ?m=nodeinfo&id=".$_GET['id']);
+		header('Location: ?m=nodeinfo&id='.$_GET['id']);
 		die;
 	}
+	else
+	{
+		header('Location: ?m=nodeinfo&id='.$_GET['id'].'&devid='.$_GET['devid']);
+		die;
+	}	
 }
 
 $nodeid = $_GET['id'];
@@ -50,11 +52,11 @@ $ownerid = $LMS->GetNodeOwner($nodeid);
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 	
 if(!isset($_GET['ownerid']))
-	$_SESSION['backto'] .= "&ownerid=".$ownerid;
+	$_SESSION['backto'] .= '&ownerid='.$ownerid;
 							
 $owner = $ownerid;
 $userinfo=$LMS->GetUser($owner);
-$layout['pagetitle'] = "Informacje o uytkowniku: ".$userinfo['username']." - edycja komputera: ".$LMS->GetNodeName($_GET['id']);
+$layout['pagetitle'] = 'Informacje o uytkowniku: '.$userinfo['username'].' - edycja komputera: '.$LMS->GetNodeName($_GET['id']);
 
 $nodeedit = $_POST['nodeedit'];
 $usernodes = $LMS->GetUserNodes($owner);
@@ -64,57 +66,46 @@ if(isset($nodeedit))
 {
 	$nodeedit['ipaddr'] = $_POST['nodeeditipaddr'];
 	$nodeedit['mac'] = $_POST['nodeeditmac'];
-	$nodeedit['mac'] = str_replace("-",":",$nodeedit['mac']);
+	$nodeedit['mac'] = str_replace('-',':',$nodeedit['mac']);
 	foreach($nodeedit as $key => $value)
 		$nodeedit[$key] = trim($value);
 	
-	if($nodeedit['ipaddr']==""&&$nodeedit['mac']==""&&$nodeedit['name']=="")
+	if($nodeedit['ipaddr']=='' && $nodeedit['mac']=='' && $nodeedit['name']=='')
 	{
-		header("Location: ?m=nodeinfo&id=".$nodeedit['id']);
+		header('Location: ?m=nodeinfo&id='.$nodeedit['id']);
 		die;
 	}
 
 	if(check_ip($nodeedit['ipaddr']))
 	{
-		if($LMS->IsIPValid($nodeedit['ipaddr']))
+		if($LMS->IsIPValid($nodeedit['ipaddr'])) 
 		{
-			if(!$LMS->IsIPFree($nodeedit['ipaddr'])&&$LMS->GetNodeIPByID($nodeedit['id'])!=$nodeedit['ipaddr'])
-			{
-				$error['ipaddr'] = "Podany adres IP jest zajty!";
-			}
+			if(!$LMS->IsIPFree($nodeedit['ipaddr']) && $LMS->GetNodeIPByID($nodeedit['id'])!=$nodeedit['ipaddr'])
+				$error['ipaddr'] = 'Podany adres IP jest zajty!';
 		}
 		else
-		{
-			$error['ipaddr'] = "Podany adres IP nie naley do adnej sieci!";
-		}
+			$error['ipaddr'] = 'Podany adres IP nie naley do adnej sieci!';
 	}
 	else
-	{
-		$error['ipaddr'] = "Podany adres IP jest niepoprawny!";
-	}
+		$error['ipaddr'] = 'Podany adres IP jest niepoprawny!';
 
 	if(check_mac($nodeedit['mac']))
 	{
-		if(
-				$LMS->GetNodeIDByMAC($nodeedit['mac']) &&
-				$LMS->GetNodeMACByID($nodeedit['id'])!=$nodeedit['mac'] &&
-				$LMS->CONFIG['phpui']['allow_mac_sharing'] == FALSE
-		)
-		{
-			$error['mac'] = "Podany adres MAC jest ju przypisany do innego komputera!";
-		}
+		if($LMS->CONFIG['phpui']['allow_mac_sharing'] == FALSE)
+			if($LMS->GetNodeIDByMAC($nodeedit['mac']) && $LMS->GetNodeMACByID($nodeedit['id'])!=$nodeedit['mac'])
+				$error['mac'] = 'Podany adres MAC jest ju przypisany do innego komputera!';
 	}
 	else
-	{
-		$error['mac'] = "Podany adres MAC jest bdny!";
-	}
+		$error['mac'] = 'Podany adres MAC jest bdny!';
 
-	if($nodeedit['name']=="")
-		$error['name'] = "Podaj nazw!";
+	if($nodeedit['name']=='')
+		$error['name'] = 'Podaj nazw!';
 	elseif($LMS->GetNodeIDByName($nodeedit['name']) && $LMS->GetNodeIDByNAME($nodeedit['name']) != $nodeedit['id'])
-		$error['name'] = "Ta nazwa jest zajta!";
+		$error['name'] = 'Ta nazwa jest zajta!';
 	elseif(!eregi("^[_a-z0-9-]+$",$nodeedit['name']))
-		$error['name'] = "Podana nazwa zawiera niepoprawne znaki!";
+		$error['name'] = 'Podana nazwa zawiera niepoprawne znaki!';
+	elseif(strlen($nodeedit['name'])>16)
+		$error['name'] = 'Podana nazwa jest za duga!';
 
 	if($nodeedit['access']!=1)
 		$nodeedit['access'] = 0;
@@ -125,7 +116,7 @@ if(isset($nodeedit))
 	{
 		$netdev = $LMS->GetNetDev($nodeedit['netdev']); 
 		if($netdev['ports'] <= $netdev['takenports'])
-		    $error['netdev'] = "Brak wolnych portw w wybranym urzdzeniu!";
+		    $error['netdev'] = 'Brak wolnych portw w wybranym urzdzeniu!';
 		$nodeinfo['netdev'] = $nodeedit['netdev'];
 	}
 	
@@ -138,7 +129,7 @@ if(isset($nodeedit))
 	if(!$error)
 	{
 		$LMS->NodeUpdate($nodeedit);
-		header("Location: ?m=nodeinfo&id=".$nodeedit['id']);
+		header('Location: ?m=nodeinfo&id='.$nodeedit['id']);
 	}
 }
 
@@ -150,7 +141,6 @@ $balancelist = $LMS->GetUserBalanceList($owner);
 $usergroups = $LMS->UsergroupGetForUser($ownerid);
 $otherusergroups = $LMS->GetGroupNamesWithoutUser($ownerid);
 
-$nodeinfo['netdev'] = $errorlinkdev ? $netdev : $LMS->GetNetDev($nodeinfo['netdev']);
 $netdevices = $LMS->GetNetDevList();
 unset($netdevices['total']);
 unset($netdevices['direction']);
