@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtqueueview.php,v 1.7 2004/07/02 11:24:52 alec Exp $
+ *  $Id: rtqueueview.php,v 1.9 2004/07/10 21:23:25 alec Exp $
  */
 
 if(! $LMS->QueueExists($_GET['id']))
@@ -38,15 +38,48 @@ if(! $LMS->GetAdminRightsRT($SESSION->id, $queuedata['id']))
 	die;
 }
 
+if(!isset($_GET['o']))
+	$o = $_SESSION['rto'];
+else
+	$o = $_GET['o'];
+$_SESSION['rto'] = $o;
+
+if(!isset($_GET['s']))
+	$s = $_SESSION['rts'];
+else
+	$s = $_GET['s'];
+$_SESSION['rts'] = $s;
+
 $queuedata['name'] = $LMS->GetQueueName($queuedata['id']);
 
 $layout['pagetitle'] = 'Podgld kolejki: '.$queuedata['name'];
-$queue = $LMS->GetQueueContent($_GET['id']);
+$queue = $LMS->GetQueueContents($_GET['id'], $o, $s);
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
+if (isset($_SESSION['rtp']) && !isset($_GET['page']))
+	$_GET['page'] = $_SESSION['rtp'];
+
+$queuedata['total'] = $queue['total'];
+$queuedata['state'] = $_SESSION['rts'];;
+$queuedata['order'] = $queue['order'];
+$queuedata['direction'] = $queue['direction'];
+unset($queue['total']);
+unset($queue['state']);
+unset($queue['order']);
+unset($queue['direction']);
+
+$page = (! $_GET['page'] ? 1 : $_GET['page']); 
+$pagelimit = (! $LMS->CONFIG['phpui']['ticketlist_pagelimit'] ? $queuedata['total'] : $LMS->CONFIG['phpui']['ticketlist_pagelimit']);
+$start = ($page - 1) * $pagelimit;
+
+$_SESSION['rtp'] = $page;
+
 $SMARTY->assign('queue', $queue);
 $SMARTY->assign('queuedata', $queuedata);
+$SMARTY->assign('pagelimit',$pagelimit);
+$SMARTY->assign('page',$page);
+$SMARTY->assign('start',$start);
 $SMARTY->display('rtqueueview.html');
 
 ?>
